@@ -20,6 +20,7 @@
  */
 
 #include "appletinterface.h"
+#include "../declarative/appletcontainer.h"
 
 #include <QAction>
 #include <QDir>
@@ -39,6 +40,7 @@
 #include <Plasma/Corona>
 #include <Plasma/Context>
 #include <Plasma/Package>
+#include <Plasma/ToolTipManager>
 
 Q_DECLARE_METATYPE(AppletInterface*)
 
@@ -420,6 +422,31 @@ AppletInterface::ItemStatus AppletInterface::status() const
     return (AppletInterface::ItemStatus)((int)(applet()->status()));
 }
 
+void AppletInterface::setHorizontalSizePolicy(QtSizePolicy horizPolicy)
+{
+    QSizePolicy policy = applet()->sizePolicy();
+    policy.setHorizontalPolicy((QSizePolicy::Policy)horizPolicy);
+    applet()->setSizePolicy(policy);
+}
+
+AppletInterface::QtSizePolicy AppletInterface::horizontalSizePolicy() const
+{
+    return (AppletInterface::QtSizePolicy)applet()->sizePolicy().horizontalPolicy();
+}
+
+
+void AppletInterface::setVerticalSizePolicy(QtSizePolicy vertPolicy)
+{
+    QSizePolicy policy = applet()->sizePolicy();
+    policy.setVerticalPolicy((QSizePolicy::Policy)vertPolicy);
+    applet()->setSizePolicy(policy);
+}
+
+AppletInterface::QtSizePolicy AppletInterface::verticalSizePolicy() const
+{
+    return (AppletInterface::QtSizePolicy)applet()->sizePolicy().verticalPolicy();
+}
+
 /*
 QString AppletInterface::downloadPath(const QString &file)
 {
@@ -447,6 +474,7 @@ PopupAppletInterface::PopupAppletInterface(AbstractJsAppletScript *parent)
     : APPLETSUPERCLASS(parent)
 {
     connect(m_appletScriptEngine, SIGNAL(popupEvent(bool)), this, SIGNAL(popupEvent(bool)));
+    connect(m_appletScriptEngine, SIGNAL(popupEvent(bool)), this, SLOT(sourceAppletPopupEvent(bool)));
 }
 
 void PopupAppletInterface::setPopupIcon(const QIcon &icon)
@@ -464,6 +492,44 @@ void PopupAppletInterface::setPopupIconByName(const QString &name)
     return popupApplet()->setPopupIcon(name);
 }
 
+void PopupAppletInterface::setPopupIconToolTip(const QVariantHash &data)
+{
+    if (data == m_rawToolTipData) {
+        return;
+    } else if (!data.contains("image") && !data.contains("mainText") &&
+               !data.contains("subText")) {
+        m_rawToolTipData = QVariantHash();
+        Plasma::ToolTipManager::self()->clearContent(popupApplet());
+        Plasma::ToolTipManager::self()->unregisterWidget(popupApplet());
+        emit popupIconToolTipChanged();
+        return;
+    }
+
+    Plasma::ToolTipContent content(data.value("mainText").toString(), data.value("subText").toString());
+
+    const QVariant image = data.value("image");
+    if (image.canConvert<QIcon>()) {
+        content.setImage(image.value<QIcon>());
+    } else if (image.canConvert<QPixmap>()) {
+        content.setImage(image.value<QPixmap>());
+    } else if (image.canConvert<QImage>()) {
+        content.setImage(QPixmap::fromImage(image.value<QImage>()));
+    } else  if (image.canConvert<QString>()) {
+        content.setImage(KIcon(image.toString()));
+    }
+
+    Plasma::ToolTipManager::self()->registerWidget(popupApplet());
+    Plasma::ToolTipManager::self()->setContent(popupApplet(), content);
+    m_rawToolTipData = data;
+    m_toolTipData = content;
+    emit popupIconToolTipChanged();
+}
+
+QVariantHash PopupAppletInterface::popupIconToolTip() const
+{
+    return m_rawToolTipData;
+}
+
 void PopupAppletInterface::setPassivePopup(bool passive)
 {
     popupApplet()->setPassivePopup(passive);
@@ -474,6 +540,16 @@ bool PopupAppletInterface::isPassivePopup() const
     return popupApplet()->isPassivePopup();
 }
 
+bool PopupAppletInterface::isPopupShowing() const
+{
+    return popupApplet()->isPopupShowing();
+}
+
+void PopupAppletInterface::setPopupShowing(bool show)
+{
+    show ? popupApplet()->showPopup() : popupApplet()->hidePopup();
+}
+
 void PopupAppletInterface::togglePopup()
 {
     popupApplet()->togglePopup();
@@ -504,9 +580,23 @@ QGraphicsWidget *PopupAppletInterface::popupWidget()
     return popupApplet()->graphicsWidget();
 }
 
+void PopupAppletInterface::sourceAppletPopupEvent(bool show)
+{
+    if (show) {
+        Plasma::ToolTipManager::self()->clearContent(popupApplet());
+    } else {
+        Plasma::ToolTipManager::self()->registerWidget(popupApplet());
+        Plasma::ToolTipManager::self()->setContent(popupApplet(), m_toolTipData);
+    }
+}
+
+
+///////////// ContainmentInterface
+
 ContainmentInterface::ContainmentInterface(AbstractJsAppletScript *parent)
     : APPLETSUPERCLASS(parent),
-      m_movableApplets(true)
+      m_movableApplets(true),
+      m_toolBox(0)
 {
     connect(containment(), SIGNAL(appletRemoved(Plasma::Applet *)), this, SLOT(appletRemovedForward(Plasma::Applet *)));
 
@@ -521,6 +611,9 @@ ContainmentInterface::ContainmentInterface(AbstractJsAppletScript *parent)
          connect(containment()->corona(), SIGNAL(availableScreenRegionChanged()),
                  this, SIGNAL(availableScreenRegionChanged()));
      }
+
+    qmlRegisterType<AppletContainer>("org.kde.plasma.containments", 0, 1, "AppletContainer");
+    qmlRegisterType<ToolBoxProxy>();
 }
 
 QScriptValue ContainmentInterface::applets()
@@ -634,6 +727,15 @@ QString ContainmentInterface::activityId() const
     return containment()->context()->currentActivityId();
 }
 
+ToolBoxProxy* ContainmentInterface::toolBox()
+{
+    if (!m_toolBox) {
+        m_toolBox = new ToolBoxProxy(containment(), this);
+        //m_appletScriptEngine->setToolBox(m_toolBox); // setToolBox() is protected :/
+    }
+    return m_toolBox;
+}
+
 #ifndef USE_JS_SCRIPTENGINE
 #include "appletinterface.moc"
 #endif
